==> hinemos_src-2.3.1.tar.gz: Hinemos_src-2.3.1/MonitorEJB/src/com/clustercontrol/monitor/ejb/mdb/SendMailBean.java <==
/*
 
 Copyright (C) 2006 NTT DATA Corporation
 
 This program is free software; you can redistribute it and/or
 Modify it under the terms of the GNU General Public License 
 as published by the Free Software Foundation, version 2.
 
 This program is distributed in the hope that it will be
 useful, but WITHOUT ANY WARRANTY; without even the implied 
 warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
 PURPOSE.  See the GNU General Public License for more details.
 
 */

package com.clustercontrol.monitor.ejb.mdb;

import javax.ejb.EJBException;
import javax.jms.JMSException;
import javax.jms.ObjectMessage;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.clustercontrol.monitor.message.LogOutputInfo;
import com.clustercontrol.monitor.message.ParallelLogOutputInfo;
import com.clustercontrol.monitor.util.SendMail;

/**
 * メール送信を行う Message-Driven Bean <BR>
 * <p>ログ出力の遅延を発生させない様、非同期で処理を行うために、
 * Message-Driven Beanでメール送信を実装します。
 *
 * <!-- begin-xdoclet-definition -->
 * @ejb.bean name="SendMailBean" 
 *     acknowledge-mode="Auto-acknowledge"
 *     destination-type="javax.jms.Queue"
 *     
 *     transaction-type="Container"
 *     destination-jndi-name="queue/clustercontrol/Monitor/SendMail"
 * 
 * @jboss.depends name="jboss.j2ee:service=EJB,jndiName=AccessController"
 * @jboss.depends name="jboss.j2ee:service=EJB,jndiName=RepositoryController"
 * @jboss.depends name="jboss.j2ee:service=EJB,jndiName=NotifyController"
 * @jboss.depends name="jboss.j2ee:service=EJB,jndiName=QuartzManager"
 * 
 * @jboss.container-configuration
 *  name="Singleton Message Driven Bean"
 * 
 *--
 * Server Runtime Specific Tags
 * If you are not using a specific runtime, you can safely remove the tags below.
 * @jonas.message-driven-destination jndi-name="queue/clustercontrol/Monitor/SendMail"
 * @jboss.destination-jndi-name name="queue/clustercontrol/Monitor/SendMail"
 *
 *--
 * <!-- end-xdoclet-definition -->
 **/
public class SendMailBean implements javax.ejb.MessageDrivenBean, javax.jms.MessageListener {
	
	/** ログ出力のインスタンス。 */
	protected static Log m_log = LogFactory.getLog( SendMailBean.class );
	
	private static SendMail m_sender = new SendMail();
	
	/** コンテキスト情報 */
	private javax.ejb.MessageDrivenContext messageContext = null;
	
	/**
	 * コンテキスト情報を設定します。<BR>
	 * Message-Driven Bean がインスタンスプールに格納される際に行う処理を実装します。
	 * @see javax.ejb.MessageDrivenBean#setMessageDrivenContext(javax.ejb.MessageDrivenContext)
	 */
	public void setMessageDrivenContext(
			javax.ejb.MessageDrivenContext messageContext)
	throws javax.ejb.EJBException {
		this.messageContext = messageContext;
	}
	
	/** 
	 * Message-Driven Bean が生成される際に行う処理を実装します。
	 * @ejb.create-method 
	 */
	public void ejbCreate() {
		//no specific action required for message-driven beans 
	}
	
	/** 
	 * コンテキスト情報をクリアします。<BR>
	 * Message-Driven Bean が削除される際に行う処理を実装します。
	 * @see javax.ejb.MessageDrivenBean#ejbRemove()
	 */
	public void ejbRemove() {
		messageContext = null;
	}
	
	/** 
	 * 引数で指定された受信メッセージを元に、メール送信をおこないます。<BR>
	 * Message-Driven Bean で行うビジネスロジックを実装します。
	 * 特定のメッセージを受信した場合のみ処理を行います。受信メッセージは下記の通りです。
	 * 
	 * <p><li>{@link com.clustercontrol.monitor.message.ParallelLogOutputInfo} : 含まれている並列処理用のログ出力情報を基にメールを送信します。
	 *
	 * @see javax.jms.MessageListener#onMessage(javax.jms.Message)
	 * 
	 * @see com.clustercontrol.monitor.util.SendMail#sendMail(String[], LogOutputInfo, Date)
	 * @see com.clustercontrol.monitor.message.ParallelLogOutputInfo
	 */
	@SuppressWarnings("unchecked")
	public void onMessage(javax.jms.Message message) {
		m_log.debug("Message Driven Bean got message " + message);

		if(message instanceof ObjectMessage) {
			ObjectMessage msg = (ObjectMessage)message;
			
			try {
				Object objMsg = msg.getObject();
				if(objMsg instanceof ParallelLogOutputInfo) {
					LogOutputInfo info = ((ParallelLogOutputInfo)objMsg).getLogOutputInfo();
					m_sender.sendMail(
							info.getAddress(), 
							info, 
							((ParallelLogOutputInfo)objMsg).getOutputDate());
				}
				else {
					m_log.debug("onMessage(): ObjectMessage is not an expected instance. " + objMsg.toString());
				}
			}
			catch(JMSException e) {
				m_log.error("onMessage():" + e.getMessage());
			}
			catch(EJBException e) {
				m_log.error("onMessage():" + e.getMessage());
			}
			catch(Exception e) {
				m_log.error("onMessage():" + e.getMessage());
			}	
		}
	}
}

==> hinemos_src-2.4.3.tar.gz: Hinemos_src-2.4.3/MonitorEJB/src/com/clustercontrol/monitor/ejb/mdb/SendMailBean.java <==
/*
 
 Copyright (C) 2006 NTT DATA Corporation
 
 This program is free software; you can redistribute it and/or
 Modify it under the terms of the GNU General Public License 
 as published by the Free Software Foundation, version 2.
 
 This program is distributed in the hope that it will be
 useful, but WITHOUT ANY WARRANTY; without even the implied 
 warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
 PURPOSE.  See the GNU General Public License for more details.
 
 */

package com.clustercontrol.monitor.ejb.mdb;

import javax.ejb.EJBException;
import javax.jms.JMSException;
import javax.jms.ObjectMessage;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.clustercontrol.monitor.message.LogOutputInfo;
import com.clustercontrol.monitor.message.ParallelLogOutputInfo;
import com.clustercontrol.monitor.util.SendMail;

/**
 * メール送信を行う Message-Driven Bean <BR>
 * <p>ログ出力の遅延を発生させない様、非同期で処理を行うために、
 * Message-Driven Beanでメール送信を実装します。
 *
 * <!-- begin-xdoclet-definition -->
 * @ejb.bean name="SendMailBean" 
 *     acknowledge-mode="Auto-acknowledge"
 *     destination-type="javax.jms.Queue"
 *     
 *     transaction-type="Container"
 *     destination-jndi-name="queue/clustercontrol/Monitor/SendMail"
 * 
 * @jboss.depends name="jboss.j2ee:service=EJB,jndiName=AccessController"
 * @jboss.depends name="jboss.j2ee:service=EJB,jndiName=RepositoryController"
 * @jboss.depends name="jboss.j2ee:service=EJB,jndiName=NotifyController"
 * @jboss.depends name="jboss.j2ee:service=EJB,jndiName=QuartzManager"
 * 
 * @jboss.container-configuration
 *  name="Singleton Message Driven Bean"
 * 
 *--
 * Server Runtime Specific Tags
 * If you are not using a specific runtime, you can safely remove the tags below.
 * @jonas.message-driven-destination jndi-name="queue/clustercontrol/Monitor/SendMail"
 * @jboss.destination-jndi-name name="queue/clustercontrol/Monitor/SendMail"
 *
 *--
 * <!-- end-xdoclet-definition -->
 **/
public class SendMailBean implements javax.ejb.MessageDrivenBean, javax.jms.MessageListener {
	
	/** ログ出力のインスタンス。 */
	protected static Log m_log = LogFactory.getLog( SendMailBean.class );
	
	private static SendMail m_sender = new SendMail();
	
	/** コンテキスト情報 */
	private javax.ejb.MessageDrivenContext messageContext = null;
	
	/**
	 * コンテキスト情報を設定します。<BR>
	 * Message-Driven Bean がインスタンスプールに格納される際に行う処理を実装します。
	 * @see javax.ejb.MessageDrivenBean#setMessageDrivenContext(javax.ejb.MessageDrivenContext)
	 */
	public void setMessageDrivenContext(
			javax.ejb.MessageDrivenContext messageContext)
	throws javax.ejb.EJBException {
		this.messageContext = messageContext;
	}
	
	/** 
	 * Message-Driven Bean が生成される際に行う処理を実装します。
	 * @ejb.create-method 
	 */
	public void ejbCreate() {
		//no specific action required for message-driven beans 
	}
	
	/** 
	 * コンテキスト情報をクリアします。<BR>
	 * Message-Driven Bean が削除される際に行う処理を実装します。
	 * @see javax.ejb.MessageDrivenBean#ejbRemove()
	 */
	public void ejbRemove() {
		messageContext = null;
	}
	
	/** 
	 * 引数で指定された受信メッセージを元に、メール送信をおこないます。<BR>
	 * Message-Driven Bean で行うビジネスロジックを実装します。
	 * 特定のメッセージを受信した場合のみ処理を行います。受信メッセージは下記の通りです。
	 * 
	 * <p><li>{@link com.clustercontrol.monitor.message.ParallelLogOutputInfo} : 含まれている並列処理用のログ出力情報を基にメールを送信します。
	 *
	 * @see javax.jms.MessageListener#onMessage(javax.jms.Message)
	 * 
	 * @see com.clustercontrol.monitor.util.SendMail#sendMail(String[], LogOutputInfo, Date)
	 * @see com.clustercontrol.monitor.message.ParallelLogOutputInfo
	 */
	@SuppressWarnings("unchecked")
	public void onMessage(javax.jms.Message message) {
		m_log.debug("Message Driven Bean got message " + message);

		if(message instanceof ObjectMessage) {
			ObjectMessage msg = (ObjectMessage)message;
			
			try {
				Object objMsg = msg.getObject();
				if(objMsg instanceof ParallelLogOutputInfo) {
					LogOutputInfo info = ((ParallelLogOutputInfo)objMsg).getLogOutputInfo();
					m_sender.sendMail(
							info.getAddress(), 
							info, 
							((ParallelLogOutputInfo)objMsg).getOutputDate());
				}
				else {
					m_log.debug("onMessage(): ObjectMessage is not an expected instance. " + objMsg.toString());
				}
			}
			catch(JMSException e) {
				m_log.error("onMessage():" + e.getMessage(), e);
			}
			catch(EJBException e) {
				m_log.error("onMessage():" + e.getMessage(), e);
			}
			catch(Exception e) {
				m_log.error("onMessage():" + e.getMessage(), e);
			}	
		}
	}
}
